==> cxf-services-xkms-common-4.0.0-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMinorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ResultMinorEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="ResultMinorEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NoMatch"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TooManyResponses"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Incomplete"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Failure"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#Refused"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NoAuthentication"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#MessageNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#UnknownResponseId"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RepresentRequired"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#NotSynchronous"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ResultMinorEnum")
@XmlEnum
public enum ResultMinorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoMatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_MATCH("http://www.w3.org/2002/03/xkms#NoMatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TooManyResponses")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TOO_MANY_RESPONSES("http://www.w3.org/2002/03/xkms#TooManyResponses"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Incomplete")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INCOMPLETE("http://www.w3.org/2002/03/xkms#Incomplete"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Failure")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_FAILURE("http://www.w3.org/2002/03/xkms#Failure"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Refused")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REFUSED("http://www.w3.org/2002/03/xkms#Refused"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoAuthentication")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_AUTHENTICATION("http://www.w3.org/2002/03/xkms#NoAuthentication"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#MessageNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_MESSAGE_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#MessageNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#UnknownResponseId")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_UNKNOWN_RESPONSE_ID("http://www.w3.org/2002/03/xkms#UnknownResponseId"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RepresentRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT_REQUIRED("http://www.w3.org/2002/03/xkms#RepresentRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NotSynchronous")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NOT_SYNCHRONOUS("http://www.w3.org/2002/03/xkms#NotSynchronous"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_OPTIONAL_ELEMENT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PROOF_OF_POSSESSION_REQUIRED("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_OUT_OF_RANGE("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange");
    private final String value;

    ResultMinorEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static ResultMinorEnum fromValue(String v) {
        for (ResultMinorEnum c: ResultMinorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-4.1.1-sources.jar: org/apache/cxf/xkms/model/xkms/ResultMinorEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * 
 * <p>Java class for ResultMinorEnum</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="ResultMinorEnum">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}anyURI">
 *     <enumeration value="http://www.w3.org/2002/03/xkms#NoMatch"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#TooManyResponses"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#Incomplete"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#Failure"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#Refused"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#NoAuthentication"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#MessageNotSupported"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#UnknownResponseId"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#RepresentRequired"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#NotSynchronous"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"/>
 *     <enumeration value="http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "ResultMinorEnum")
@XmlEnum
public enum ResultMinorEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoMatch")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_MATCH("http://www.w3.org/2002/03/xkms#NoMatch"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TooManyResponses")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TOO_MANY_RESPONSES("http://www.w3.org/2002/03/xkms#TooManyResponses"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Incomplete")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_INCOMPLETE("http://www.w3.org/2002/03/xkms#Incomplete"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Failure")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_FAILURE("http://www.w3.org/2002/03/xkms#Failure"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#Refused")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REFUSED("http://www.w3.org/2002/03/xkms#Refused"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NoAuthentication")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NO_AUTHENTICATION("http://www.w3.org/2002/03/xkms#NoAuthentication"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#MessageNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_MESSAGE_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#MessageNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#UnknownResponseId")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_UNKNOWN_RESPONSE_ID("http://www.w3.org/2002/03/xkms#UnknownResponseId"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RepresentRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_REPRESENT_REQUIRED("http://www.w3.org/2002/03/xkms#RepresentRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#NotSynchronous")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_NOT_SYNCHRONOUS("http://www.w3.org/2002/03/xkms#NotSynchronous"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_OPTIONAL_ELEMENT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#OptionalElementNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PROOF_OF_POSSESSION_REQUIRED("http://www.w3.org/2002/03/xkms#ProofOfPossessionRequired"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_NOT_SUPPORTED("http://www.w3.org/2002/03/xkms#TimeInstantNotSupported"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_TIME_INSTANT_OUT_OF_RANGE("http://www.w3.org/2002/03/xkms#TimeInstantOutOfRange");
    private final String value;

    ResultMinorEnum(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static ResultMinorEnum fromValue(String v) {
        for (ResultMinorEnum c: ResultMinorEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
